@@ -45,7 +45,7 @@
 DECLARATION_BEGIN
 
 /* OSSP uuid version (compile-time information) */
-#define UUID_VERSION  0x102200
+#define UUID_VERSION  0x103202
 
 /* encoding octet stream lengths */
 #define UUID_LEN_BIN  (128 /*bit*/ / 8 /*bytes*/)
@@ -82,20 +82,21 @@ struct uuid_st;
 typedef struct uuid_st uuid_t;
 
 /* UUID object handling */
-extern uuid_rc_t     uuid_create   (uuid_t **_uuid);
-extern uuid_rc_t     uuid_destroy  (uuid_t  *_uuid);
+extern uuid_rc_t     uuid_create   (      uuid_t **_uuid);
+extern uuid_rc_t     uuid_destroy  (      uuid_t  *_uuid);
+extern uuid_rc_t     uuid_clone    (const uuid_t  *_uuid, uuid_t **_clone);
 
 /* UUID generation */
-extern uuid_rc_t     uuid_load     (uuid_t  *_uuid, const char *_name);
-extern uuid_rc_t     uuid_make     (uuid_t  *_uuid, unsigned int _mode, ...);
+extern uuid_rc_t     uuid_load     (      uuid_t  *_uuid, const char *_name);
+extern uuid_rc_t     uuid_make     (      uuid_t  *_uuid, unsigned int _mode, ...);
 
 /* UUID comparison */
-extern uuid_rc_t     uuid_isnil    (uuid_t  *_uuid,                 int *_result);
-extern uuid_rc_t     uuid_compare  (uuid_t  *_uuid, uuid_t *_uuid2, int *_result);
+extern uuid_rc_t     uuid_isnil    (const uuid_t  *_uuid,                       int *_result);
+extern uuid_rc_t     uuid_compare  (const uuid_t  *_uuid, const uuid_t *_uuid2, int *_result);
 
 /* UUID import/export */
-extern uuid_rc_t     uuid_import   (uuid_t  *_uuid, uuid_fmt_t _fmt, const void  *_data_ptr, size_t  _data_len);
-extern uuid_rc_t     uuid_export   (uuid_t  *_uuid, uuid_fmt_t _fmt,       void **_data_ptr, size_t *_data_len);
+extern uuid_rc_t     uuid_import   (      uuid_t  *_uuid, uuid_fmt_t _fmt, const void  *_data_ptr, size_t  _data_len);
+extern uuid_rc_t     uuid_export   (const uuid_t  *_uuid, uuid_fmt_t _fmt,       void **_data_ptr, size_t *_data_len);
 
 /* library utilities */
 extern char         *uuid_error    (uuid_rc_t _rc);
